# Flow Control Actions

https://docs.aws.amazon.com/connect/latest/APIReference/flow-control-actions.html

Actions that control flow behavior by enabling/disabling features or choosing branches. No side effects, no contact/participant required.

## Implementation Status

| Block | Status | Notes |
|-------|--------|-------|
| CheckHoursOfOperation | Implemented | Basic implementation |
| CheckMetricData | Implemented | Basic implementation |
| CheckOutboundCallStatus | Not Implemented | |
| CheckVoiceId | Not Implemented | |
| Compare | Implemented | Basic implementation |
| DistributeByPercentage | Implemented | Basic implementation |
| EndFlowExecution | Implemented | Basic implementation |
| GetMetricData | Not Implemented | |
| Loop | Not Implemented | |
| StartVoiceIdStream | Not Implemented | |
| TransferToFlow | Implemented | Basic implementation |
| UpdateFlowAttributes | Not Implemented | |
| UpdateFlowLoggingBehavior | Not Implemented | |
| UpdateRoutingCriteria | Not Implemented | |
| Wait | Implemented | Basic implementation |

## Implemented: 7/15
